/***************************************************************************
 *   Copyright (C) 2003-2005 by Michael Goettsche                          *
 *   mail@tuxipuxi.org                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef ADDNEWSTREAMIMPL_H
#define ADDNEWSTREAMIMPL_H

#include "addnewstream.h"

class AddNewStreamImpl : public AddNewStream
{
	TQ_OBJECT
  

public:
 
	AddNewStreamImpl( TQWidget* parent = 0, const char* name = 0 );
	~AddNewStreamImpl();

protected:

protected slots:
 
	void okButtonClicked();
	void cancelButtonClicked();
	
signals:

	void finished( AddNewStreamImpl* );
};

#endif

